#!/usr/bin/python3
# -*- coding: utf-8 -*-


from .update import main as update
from .uninstall import main as uninstall
from .reinstall import main as reinstall
from .postinstall import main as postinstall
from .dependency import main as dependency
